summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIan Abbott <abbotti@mev.co.uk>2026-01-29 14:44:02 +0300
committerGreg Kroah-Hartman <gregkh@linuxfoundation.org>2026-04-02 16:49:48 +0300
commitb5720dabb04263c8fffc24983023a4e1f384049f (patch)
tree123a725ea8ffe8a1fa9673cd9e0b4c2fc82e7fd1
parentae377d6afbd5618500edf0954edfc15aa28b162c (diff)
downloadlinux-b5720dabb04263c8fffc24983023a4e1f384049f.tar.xz
comedi: Correct name of ACCES I/O Products
Commit 6cd5a9a35c3d ("staging/trivial: fix typos concerning "access"") accidentally changed "Acces I/O Products" to "Access I/O Products", although "Acces" should actually be a capitalized acronym "ACCES" (standing for "Acquisition, Control, and Communication: Engineering & Systems"). Change it in the "aio_aio12_8" and "aio_iiro_16" drivers and change the Kconfig file to match. Signed-off-by: Ian Abbott <abbotti@mev.co.uk> Link: https://patch.msgid.link/20260129114402.11033-1-abbotti@mev.co.uk Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
-rw-r--r--drivers/comedi/Kconfig10
-rw-r--r--drivers/comedi/drivers/aio_aio12_8.c12
-rw-r--r--drivers/comedi/drivers/aio_iiro_16.c8
3 files changed, 15 insertions, 15 deletions
diff --git a/drivers/comedi/Kconfig b/drivers/comedi/Kconfig
index 6dcc2567de6d..c34a8d68547b 100644
--- a/drivers/comedi/Kconfig
+++ b/drivers/comedi/Kconfig
@@ -405,20 +405,20 @@ config COMEDI_FL512
called fl512.
config COMEDI_AIO_AIO12_8
- tristate "I/O Products PC/104 AIO12-8 Analog I/O Board support"
+ tristate "ACCES I/O Products PC/104 AIO12-8 Analog I/O Board support"
select COMEDI_8254
select COMEDI_8255
help
- Enable support for I/O Products PC/104 AIO12-8 Analog I/O Board
+ Enable support for ACCES I/O Products PC/104 AIO12-8 Analog I/O Board
To compile this driver as a module, choose M here: the module will be
called aio_aio12_8.
config COMEDI_AIO_IIRO_16
- tristate "I/O Products PC/104 IIRO16 Board support"
+ tristate "ACCES I/O Products PC/104 IIRO16 Board support"
help
- Enable support for I/O Products PC/104 IIRO16 Relay And Isolated
- Input Board
+ Enable support for ACCES I/O Products PC/104 IIRO16 Relay And
+ Isolated Input Board
To compile this driver as a module, choose M here: the module will be
called aio_iiro_16.
diff --git a/drivers/comedi/drivers/aio_aio12_8.c b/drivers/comedi/drivers/aio_aio12_8.c
index 1d9e14981928..e0cbc2ec7c4d 100644
--- a/drivers/comedi/drivers/aio_aio12_8.c
+++ b/drivers/comedi/drivers/aio_aio12_8.c
@@ -1,17 +1,17 @@
// SPDX-License-Identifier: GPL-2.0+
/*
* aio_aio12_8.c
* Driver for Access I/O Products PC-104 AIO12-8 Analog I/O Board
* Copyright (C) 2006 C&C Technologies, Inc.
*/
/*
* Driver: aio_aio12_8
* Description: Access I/O Products PC-104 AIO12-8 Analog I/O Board
* Author: Pablo Mejia <pablo.mejia@cctechnol.com>
- * Devices: [Access I/O] PC-104 AIO12-8 (aio_aio12_8),
- * [Access I/O] PC-104 AI12-8 (aio_ai12_8),
- * [Access I/O] PC-104 AO12-4 (aio_ao12_4)
+ * Devices: [ACCES I/O] PC-104 AIO12-8 (aio_aio12_8),
+ * [ACCES I/O] PC-104 AI12-8 (aio_ai12_8),
+ * [ACCES I/O] PC-104 AO12-4 (aio_ao12_4)
* Status: experimental
*
* Configuration Options:
@@ -273,5 +273,5 @@ static struct comedi_driver aio_aio12_8_driver = {
module_comedi_driver(aio_aio12_8_driver);
MODULE_AUTHOR("Comedi https://www.comedi.org");
-MODULE_DESCRIPTION("Comedi driver for Access I/O AIO12-8 Analog I/O Board");
+MODULE_DESCRIPTION("Comedi driver for ACCES I/O AIO12-8 Analog I/O Board");
MODULE_LICENSE("GPL");
@@ -1,17 +1,17 @@
/*
* aio_aio12_8.c
- * Driver for Access I/O Products PC-104 AIO12-8 Analog I/O Board
+ * Driver for ACCES I/O Products PC-104 AIO12-8 Analog I/O Board
* Copyright (C) 2006 C&C Technologies, Inc.
*/
@@ -1,17 +1,17 @@
/*
* Driver: aio_aio12_8
- * Description: Access I/O Products PC-104 AIO12-8 Analog I/O Board
+ * Description: ACCES I/O Products PC-104 AIO12-8 Analog I/O Board
* Author: Pablo Mejia <pablo.mejia@cctechnol.com>
diff --git a/drivers/comedi/drivers/aio_iiro_16.c b/drivers/comedi/drivers/aio_iiro_16.c
index 00d0bb0f6256..d5d18fa2c638 100644
--- a/drivers/comedi/drivers/aio_iiro_16.c
+++ b/drivers/comedi/drivers/aio_iiro_16.c
@@ -1,15 +1,15 @@
// SPDX-License-Identifier: GPL-2.0+
/*
* aio_iiro_16.c
* Comedi driver for Access I/O Products 104-IIRO-16 board
* Copyright (C) 2006 C&C Technologies, Inc.
*/
/*
* Driver: aio_iiro_16
* Description: Access I/O Products PC/104 Isolated Input/Relay Output Board
* Author: Zachary Ware <zach.ware@cctechnol.com>
- * Devices: [Access I/O] 104-IIRO-16 (aio_iiro_16)
+ * Devices: [ACCES I/O] 104-IIRO-16 (aio_iiro_16)
* Status: experimental
*
* Configuration Options:
@@ -232,5 +232,5 @@ static struct comedi_driver aio_iiro_16_driver = {
module_comedi_driver(aio_iiro_16_driver);
MODULE_AUTHOR("Comedi https://www.comedi.org");
-MODULE_DESCRIPTION("Comedi driver for Access I/O Products 104-IIRO-16 board");
+MODULE_DESCRIPTION("Comedi driver for ACCES I/O Products 104-IIRO-16 board");
MODULE_LICENSE("GPL");
@@ -1,15 +1,15 @@
/*
* aio_iiro_16.c
- * Comedi driver for Access I/O Products 104-IIRO-16 board
+ * Comedi driver for ACCES I/O Products 104-IIRO-16 board
* Copyright (C) 2006 C&C Technologies, Inc.
*/
@@ -1,15 +1,15 @@
/*
* Driver: aio_iiro_16
- * Description: Access I/O Products PC/104 Isolated Input/Relay Output Board
+ * Description: ACCES I/O Products PC/104 Isolated Input/Relay Output Board
* Author: Zachary Ware <zach.ware@cctechnol.com>